# 🧞‍♂️ Medyum
Stack-oriented programming language in Turkish. Just for fun.

Türkçe yığın odaklı programlama dili. Yalnızca eğlence için.

Yığın odaklı programlama dilleri hakkında daha fazla bilgiyi [bu wikide](https://en.wikipedia.org/wiki/Stack-oriented_programming) okuyabilirsiniz. Medyum henüz temel seviyededir. (Şimdilik) yalnızca integer veri tipi desteklenmektedir, buna rağmen matematiksel ve mantıksal operatörler, değişkenler, koşul ifadeler, döngüler dile eklenmiştir Geliştirilmeye açıktır :) .

Ayrıca yapılacak bir `yığın` başka iş yokmuş gibi vscode'a syntax highlight desteği de eklenmiştir. [Marketplace](https://marketplace.visualstudio.com/items?itemName=orhanemredev.medyum-syntax)'de göz atın. 

## Hızlı Başlangıç
```terminal
$ pip install medyum
$ medyum <DOSYA_ADI>.med
```

## Geliştirici Ortamı
```terminal
$ git clone https://github.com/orhanemree/medyum-lang.git
$ cd medyum-lang
```

## Belgeler
* [DOCUMENTATION.md](./DOCUMENTATION.md).

## Yapılacaklar
* [ ] Örnekler.
* [ ] Gelişmiş hata raporlama.
* [ ] String veri tipi desteği.

## Referanslar
* [Tsoding/Porth Ep.01 [Video]](https://www.youtube.com/watch?v=8QP2fDBIxjM)

## Lisans
* [MIT Lisansı](./LICENSE).